@@ -810,10 +810,7 @@ function sq_send_mail($to, $subject, $body, $from, $cc='', $bcc='', $message='')
 {
 
    require_once(SM_PATH . 'functions/mime.php');
-   require_once(SM_PATH . 'class/mime/Message.class.php');
-   require_once(SM_PATH . 'class/mime/Rfc822Header.class.php');
-   require_once(SM_PATH . 'class/mime/ContentType.class.php');
-   require_once(SM_PATH . 'class/mime/AddressStructure.class.php');
+   require_once(SM_PATH . 'class/mime.class.php');
 
    if (empty($message))
    {
@@ -891,3 +888,24 @@ function sq_send_mail($to, $subject, $body, $from, $cc='', $bcc='', $message='')
 
 
 
+//
+// taken from functions/html.php on 2008/05/21
+// since 1.5.2
+//
+if (!function_exists('set_uri_vars'))
+{
+function set_uri_vars($uri, $values, $sanitize=TRUE) {
+    foreach ($values as $key => $value)
+        if (is_array($value)) {
+          $i = 0;
+          foreach ($value as $val)
+             $uri = set_url_var($uri, $key . '[' . $i++ . ']', $val, $sanitize);
+        }
+        else
+          $uri = set_url_var($uri, $key, $value, $sanitize);
+    return $uri;
+}
+}
+
+
+
